==> libreoffice_25.8.4-1.debian.tar.xz: pdfium/xfa/fgas/graphics/cfgas_geshading.h <==
// Copyright 2016 The PDFium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Original code copyright 2014 Foxit Software Inc. http://www.foxitsoftware.com

#ifndef XFA_FGAS_GRAPHICS_CFGAS_GESHADING_H_
#define XFA_FGAS_GRAPHICS_CFGAS_GESHADING_H_

#include <stddef.h>

#include <array>

#include "core/fxcrt/fx_coordinates.h"
#include "core/fxge/dib/fx_dib.h"

class CFGAS_GEShading final {
 public:
  enum class Type { kAxial = 1, kRadial };

  // Axial shading.
  CFGAS_GEShading(const CFX_PointF& beginPoint,
                  const CFX_PointF& endPoint,
                  bool isExtendedBegin,
                  bool isExtendedEnd,
                  FX_ARGB beginArgb,
                  FX_ARGB endArgb);

  // Radial shading.
  CFGAS_GEShading(const CFX_PointF& beginPoint,
                  const CFX_PointF& endPoint,
                  float beginRadius,
                  float endRadius,
                  bool isExtendedBegin,
                  bool isExtendedEnd,
                  FX_ARGB beginArgb,
                  FX_ARGB endArgb);

  ~CFGAS_GEShading();

  Type GetType() const { return m_type; }
  CFX_PointF GetBeginPoint() const { return m_beginPoint; }
  CFX_PointF GetEndPoint() const { return m_endPoint; }
  float GetBeginRadius() const { return m_beginRadius; }
  float GetEndRadius() const { return m_endRadius; }
  bool IsExtendedBegin() const { return m_isExtendedBegin; }
  bool IsExtendedEnd() const { return m_isExtendedEnd; }
  FX_ARGB GetArgb(float value) const {
    return m_argbArray[static_cast<size_t>(value * (kSteps - 1))];
  }

 private:
  static constexpr size_t kSteps = 256;

  void InitArgbArray(FX_ARGB begin_argb, FX_ARGB end_argb);

  const Type m_type;
  const CFX_PointF m_beginPoint;
  const CFX_PointF m_endPoint;
  const float m_beginRadius;
  const float m_endRadius;
  const bool m_isExtendedBegin;
  const bool m_isExtendedEnd;
  std::array<FX_ARGB, kSteps> m_argbArray;
};

#endif  // XFA_FGAS_GRAPHICS_CFGAS_GESHADING_H_

==> libreoffice_26.2.1~rc1-1.debian.tar.xz: pdfium/xfa/fgas/graphics/cfgas_geshading.h <==
// Copyright 2016 The PDFium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Original code copyright 2014 Foxit Software Inc. http://www.foxitsoftware.com

#ifndef XFA_FGAS_GRAPHICS_CFGAS_GESHADING_H_
#define XFA_FGAS_GRAPHICS_CFGAS_GESHADING_H_

#include <stddef.h>

#include <array>

#include "core/fxcrt/fx_coordinates.h"
#include "core/fxge/dib/fx_dib.h"

class CFGAS_GEShading final {
 public:
  enum class Type { kAxial = 1, kRadial };

  // Axial shading.
  CFGAS_GEShading(const CFX_PointF& beginPoint,
                  const CFX_PointF& endPoint,
                  bool isExtendedBegin,
                  bool isExtendedEnd,
                  FX_ARGB beginArgb,
                  FX_ARGB endArgb);

  // Radial shading.
  CFGAS_GEShading(const CFX_PointF& beginPoint,
                  const CFX_PointF& endPoint,
                  float beginRadius,
                  float endRadius,
                  bool isExtendedBegin,
                  bool isExtendedEnd,
                  FX_ARGB beginArgb,
                  FX_ARGB endArgb);

  ~CFGAS_GEShading();

  Type GetType() const { return type_; }
  CFX_PointF GetBeginPoint() const { return begin_point_; }
  CFX_PointF GetEndPoint() const { return end_point_; }
  float GetBeginRadius() const { return begin_radius_; }
  float GetEndRadius() const { return end_radius_; }
  bool IsExtendedBegin() const { return is_extended_begin_; }
  bool IsExtendedEnd() const { return is_extended_end_; }
  FX_ARGB GetArgb(float value) const {
    return argb_array_[static_cast<size_t>(value * (kSteps - 1))];
  }

 private:
  static constexpr size_t kSteps = 256;

  void InitArgbArray(FX_ARGB begin_argb, FX_ARGB end_argb);

  const Type type_;
  const CFX_PointF begin_point_;
  const CFX_PointF end_point_;
  const float begin_radius_;
  const float end_radius_;
  const bool is_extended_begin_;
  const bool is_extended_end_;
  std::array<FX_ARGB, kSteps> argb_array_;
};

#endif  // XFA_FGAS_GRAPHICS_CFGAS_GESHADING_H_
